@@ -51,7 +51,13 @@ import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.io.InterruptedIOException;
-import java.util.*;
+import java.util.Comparator;
+import java.util.LinkedList;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.Queue;
+import java.util.UUID;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ExecutionException;
@@ -66,6 +72,7 @@ public class GrpcLogAppender extends LogAppenderBase {
 
   private enum BatchLogKey implements BatchLogger.Key {
     RESET_CLIENT,
+    INCONSISTENCY_REPLY,
     APPEND_LOG_RESPONSE_HANDLER_ON_ERROR
   }
 
@@ -170,7 +177,7 @@ public class GrpcLogAppender extends LogAppenderBase {
   public GrpcLogAppender(RaftServer.Division server, LeaderState leaderState, FollowerInfo f) {
     super(server, leaderState, f);
 
-    Preconditions.assertNotNull(getServerRpc(), "getServerRpc()");
+    Objects.requireNonNull(getServerRpc(), "getServerRpc() == null");
 
     final RaftProperties properties = server.getRaftServer().getProperties();
     this.maxPendingRequestsNum = GrpcConfigKeys.Server.leaderOutstandingAppendsMax(properties);
@@ -192,8 +199,8 @@ public class GrpcLogAppender extends LogAppenderBase {
   }
 
   @Override
-  public GrpcService getServerRpc() {
-    return (GrpcService)super.getServerRpc();
+  public GrpcServicesImpl getServerRpc() {
+    return (GrpcServicesImpl)super.getServerRpc();
   }
 
   private GrpcServerProtocolClient getClient() throws IOException {
@@ -217,7 +224,7 @@ public class GrpcLogAppender extends LogAppenderBase {
           .orElseGet(f::getMatchIndex);
       if (event.isError() && request == null) {
         final long followerNextIndex = f.getNextIndex();
-        BatchLogger.warn(BatchLogKey.RESET_CLIENT, f.getId() + "-" + followerNextIndex, suffix ->
+        BatchLogger.print(BatchLogKey.RESET_CLIENT, f.getId() + "-" + followerNextIndex, suffix ->
             LOG.warn("{}: Follower failed (request=null, errorCount={}); keep nextIndex ({}) unchanged and retry.{}",
                 this, errorCount, followerNextIndex, suffix), logMessageBatchDuration);
         return;
@@ -419,7 +426,7 @@ public class GrpcLogAppender extends LogAppenderBase {
 
   private void sendRequest(AppendEntriesRequest request,
       AppendEntriesRequestProto proto) throws InterruptedIOException {
-    CodeInjectionForTesting.execute(GrpcService.GRPC_SEND_SERVER_REQUEST,
+    CodeInjectionForTesting.execute(GrpcServicesImpl.GRPC_SEND_SERVER_REQUEST,
         getServer().getId(), null, proto);
     resetHeartbeatTrigger();
 
@@ -516,8 +523,9 @@ public class GrpcLogAppender extends LogAppenderBase {
           break;
         case INCONSISTENCY:
           grpcServerMetrics.onRequestInconsistency(getFollowerId().toString());
-          LOG.warn("{}: received {} reply with nextIndex {}, errorCount={}, request={}",
-              this, reply.getResult(), reply.getNextIndex(), errorCount, request);
+          BatchLogger.print(BatchLogKey.INCONSISTENCY_REPLY, getFollower().getName() + "_" + reply.getNextIndex(),
+              suffix -> LOG.warn("{}: received {} reply with nextIndex {}, errorCount={}, request={} {}",
+              this, reply.getResult(), reply.getNextIndex(), errorCount, request, suffix));
           final long requestFirstIndex = request != null? request.getFirstIndex(): RaftLog.INVALID_LOG_INDEX;
           updateNextIndex(getNextIndexForInconsistency(requestFirstIndex, reply.getNextIndex()));
           break;
@@ -537,7 +545,7 @@ public class GrpcLogAppender extends LogAppenderBase {
         LOG.info("{} is already stopped", GrpcLogAppender.this);
         return;
       }
-      BatchLogger.warn(BatchLogKey.APPEND_LOG_RESPONSE_HANDLER_ON_ERROR, AppendLogResponseHandler.this.name,
+      BatchLogger.print(BatchLogKey.APPEND_LOG_RESPONSE_HANDLER_ON_ERROR, AppendLogResponseHandler.this.name,
           suffix -> GrpcUtil.warn(LOG, () -> this + ": Failed appendEntries" + suffix, t),
           logMessageBatchDuration, t instanceof StatusRuntimeException);
       grpcServerMetrics.onRequestRetry(); // Update try counter
