@@ -78,6 +78,8 @@ public class GrpcServerProtocolClient implements Closeable {
       GrpcTlsConfig tlsConfig) {
     NettyChannelBuilder channelBuilder =
         NettyChannelBuilder.forTarget(target.getAddress());
+    // ignore any http proxy for grpc
+    channelBuilder.proxyDetector(uri -> null);
 
     if (tlsConfig!= null) {
       SslContextBuilder sslContextBuilder = GrpcSslContexts.forClient();
@@ -139,7 +141,7 @@ public class GrpcServerProtocolClient implements Closeable {
   StreamObserver<InstallSnapshotRequestProto> installSnapshot(
       String name, TimeDuration timeout, int limit, StreamObserver<InstallSnapshotReplyProto> responseHandler) {
     return StreamObserverWithTimeout.newInstance(name, ServerStringUtils::toInstallSnapshotRequestString,
-        timeout, limit, i -> asyncStub.withInterceptors(i).installSnapshot(responseHandler));
+        () -> timeout, limit, i -> asyncStub.withInterceptors(i).installSnapshot(responseHandler));
   }
 
   // short-circuit the backoff timer and make them reconnect immediately.
