@@ -29,6 +29,8 @@ import org.apache.ratis.thirdparty.io.grpc.StatusRuntimeException;
 import org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver;
 import org.apache.ratis.proto.RaftProtos.*;
 import org.apache.ratis.proto.grpc.RaftServerProtocolServiceGrpc.RaftServerProtocolServiceImplBase;
+import org.apache.ratis.util.BatchLogger;
+import org.apache.ratis.util.MemoizedSupplier;
 import org.apache.ratis.util.ProtoUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -43,6 +45,11 @@ import java.util.function.Supplier;
 class GrpcServerProtocolService extends RaftServerProtocolServiceImplBase {
   public static final Logger LOG = LoggerFactory.getLogger(GrpcServerProtocolService.class);
 
+  private enum BatchLogKey implements BatchLogger.Key {
+    COMPLETED_REQUEST,
+    COMPLETED_REPLY
+  }
+
   static class PendingServerRequest<REQUEST> {
     private final REQUEST request;
     private final CompletableFuture<Void> future = new CompletableFuture<>();
@@ -62,6 +69,7 @@ class GrpcServerProtocolService extends RaftServerProtocolServiceImplBase {
 
   abstract class ServerRequestStreamObserver<REQUEST, REPLY> implements StreamObserver<REQUEST> {
     private final RaftServer.Op op;
+    private final Supplier<String> nameSupplier;
     private final StreamObserver<REPLY> responseObserver;
     /** For ordered {@link #onNext(Object)} requests. */
     private final AtomicReference<PendingServerRequest<REQUEST>> previousOnNext = new AtomicReference<>();
@@ -72,9 +80,14 @@ class GrpcServerProtocolService extends RaftServerProtocolServiceImplBase {
 
     ServerRequestStreamObserver(RaftServer.Op op, StreamObserver<REPLY> responseObserver) {
       this.op = op;
+      this.nameSupplier = MemoizedSupplier.valueOf(() -> getId() + "_" + op);
       this.responseObserver = responseObserver;
     }
 
+    String getName() {
+      return nameSupplier.get();
+    }
+
     private String getPreviousRequestString() {
       return Optional.ofNullable(previousOnNext.get())
           .map(PendingServerRequest::getRequest)
@@ -154,9 +167,12 @@ class GrpcServerProtocolService extends RaftServerProtocolServiceImplBase {
     @Override
     public void onCompleted() {
       if (isClosed.compareAndSet(false, true)) {
-        LOG.info("{}: Completed {}, lastRequest: {}", getId(), op, getPreviousRequestString());
+        BatchLogger.print(BatchLogKey.COMPLETED_REQUEST, getName(),
+            suffix -> LOG.info("{}: Completed {}, lastRequest: {} {}",
+                getId(), op, getPreviousRequestString(), suffix));
         requestFuture.get().thenAccept(reply -> {
-          LOG.info("{}: Completed {}, lastReply: {}", getId(), op, reply);
+          BatchLogger.print(BatchLogKey.COMPLETED_REPLY, getName(),
+              suffix -> LOG.info("{}: Completed {}, lastReply: {} {}", getId(), op, reply, suffix));
           responseObserver.onCompleted();
         });
       }
