@@ -49,6 +49,7 @@ import org.apache.ratis.server.protocol.TermIndex;
 import org.apache.ratis.server.raftlog.LogEntryHeader;
 import org.apache.ratis.server.raftlog.LogProtoUtils;
 import org.apache.ratis.server.raftlog.RaftLog;
+import org.apache.ratis.server.util.ServerStringUtils;
 import org.apache.ratis.statemachine.TransactionContext;
 import org.apache.ratis.util.CodeInjectionForTesting;
 import org.apache.ratis.util.CollectionUtils;
@@ -110,12 +111,10 @@ class LeaderStateImpl implements LeaderState {
     }
 
     private final Type type;
-    private final long newTerm;
     private final Runnable handler;
 
-    StateUpdateEvent(Type type, long newTerm, Runnable handler) {
+    StateUpdateEvent(Type type, Runnable handler) {
       this.type = type;
-      this.newTerm = newTerm;
       this.handler = handler;
     }
 
@@ -131,25 +130,30 @@ class LeaderStateImpl implements LeaderState {
         return false;
       }
       final StateUpdateEvent that = (StateUpdateEvent)obj;
-      return this.type == that.type && this.newTerm == that.newTerm;
+      return this.type == that.type;
     }
 
     @Override
     public int hashCode() {
-      return Objects.hash(type, newTerm);
+      return type.hashCode();
     }
 
     @Override
     public String toString() {
-      return type + (newTerm >= 0? ":" + newTerm: "");
+      return type.name();
     }
   }
 
   private class EventQueue {
-    private final String name = server.getMemberId() + "-" + JavaUtils.getClassSimpleName(getClass());
-    private final BlockingQueue<StateUpdateEvent> queue = new ArrayBlockingQueue<>(4096);
+    private final String name = ServerStringUtils.generateUnifiedName(server.getMemberId(), getClass());
+    private final BlockingQueue<StateUpdateEvent> queue = new ArrayBlockingQueue<>(
+        StateUpdateEvent.Type.values().length);;
 
-    void submit(StateUpdateEvent event) {
+    // submit can be invoked by different threads -- need to be synchronized
+    synchronized void submit(StateUpdateEvent event) {
+      if (queue.contains(event)) { // avoid duplicated events
+        return;
+      }
       try {
         queue.put(event);
       } catch (InterruptedException e) {
@@ -158,10 +162,10 @@ class LeaderStateImpl implements LeaderState {
       }
     }
 
+    // poll is invoked only by the EventProcessor thread -- synchronized is not needed
     StateUpdateEvent poll() {
-      final StateUpdateEvent e;
       try {
-        e = queue.poll(server.getMaxTimeoutMs(), TimeUnit.MILLISECONDS);
+        return queue.poll(server.getMaxTimeoutMs(), TimeUnit.MILLISECONDS);
       } catch (InterruptedException ie) {
         Thread.currentThread().interrupt();
         String s = this + ": poll() is interrupted";
@@ -172,14 +176,6 @@ class LeaderStateImpl implements LeaderState {
           throw new IllegalStateException(s + " UNEXPECTEDLY", ie);
         }
       }
-
-      if (e != null) {
-        // remove duplicated events from the head.
-        while(e.equals(queue.peek())) {
-          queue.poll();
-        }
-      }
-      return e;
     }
 
     @Override
@@ -321,9 +317,9 @@ class LeaderStateImpl implements LeaderState {
   }
 
   private final StateUpdateEvent updateCommitEvent =
-      new StateUpdateEvent(StateUpdateEvent.Type.UPDATE_COMMIT, -1, this::updateCommit);
+      new StateUpdateEvent(StateUpdateEvent.Type.UPDATE_COMMIT, this::updateCommit);
   private final StateUpdateEvent checkStagingEvent =
-      new StateUpdateEvent(StateUpdateEvent.Type.CHECK_STAGING, -1, this::checkStaging);
+      new StateUpdateEvent(StateUpdateEvent.Type.CHECK_STAGING, this::checkStaging);
 
   private final String name;
   private final RaftServerImpl server;
@@ -360,7 +356,7 @@ class LeaderStateImpl implements LeaderState {
   private final LeaderLease lease;
 
   LeaderStateImpl(RaftServerImpl server) {
-    this.name = server.getMemberId() + "-" + JavaUtils.getClassSimpleName(getClass());
+    this.name = ServerStringUtils.generateUnifiedName(server.getMemberId(), getClass());
     this.server = server;
 
     final RaftProperties properties = server.getRaftServer().getProperties();
@@ -701,7 +697,7 @@ class LeaderStateImpl implements LeaderState {
   }
 
   void submitStepDownEvent(long term, StepDownReason reason) {
-    eventQueue.submit(new StateUpdateEvent(StateUpdateEvent.Type.STEP_DOWN, term, () -> stepDown(term, reason)));
+    eventQueue.submit(new StateUpdateEvent(StateUpdateEvent.Type.STEP_DOWN, () -> stepDown(term, reason)));
   }
 
   private void stepDown(long term, StepDownReason reason) {
@@ -797,6 +793,7 @@ class LeaderStateImpl implements LeaderState {
           follower.getLastRpcResponseTime().elapsedTimeMs());
       return BootStrapProgress.NOPROGRESS;
     } else if (follower.getMatchIndex() + stagingCatchupGap > committed
+        && follower.getMatchIndex() >= server.getRaftConf().getLogEntryIndex()
         && follower.getLastRpcResponseTime().compareTo(progressTime) > 0
         && follower.hasAttemptedToInstallSnapshot()) {
       return BootStrapProgress.CAUGHTUP;
@@ -817,7 +814,9 @@ class LeaderStateImpl implements LeaderState {
 
   @Override
   public boolean isFollowerBootstrapping(FollowerInfo follower) {
-    return isBootStrappingPeer(follower.getId());
+    // It is better to check caught up than staging state
+    // since a follower may have already caught up but still in the staging state.
+    return !isCaughtUp(follower);
   }
 
   private void checkStaging() {
@@ -849,7 +848,12 @@ class LeaderStateImpl implements LeaderState {
   }
 
   boolean isBootStrappingPeer(RaftPeerId peerId) {
-    return Optional.ofNullable(stagingState).map(s -> s.contains(peerId)).orElse(false);
+    final Optional<LogAppender> info = getLogAppender(peerId);
+    if (info.isPresent()) {
+      return !isCaughtUp(info.get().getFollower());
+    }
+    final ConfigurationStagingState staging = stagingState;
+    return staging != null && staging.contains(peerId);
   }
 
   void submitUpdateCommitEvent() {
@@ -1212,6 +1216,10 @@ class LeaderStateImpl implements LeaderState {
     return getLogAppenders().mapToLong(s -> s.getFollower().getNextIndex()).toArray();
   }
 
+  long[] getFollowerMatchIndices() {
+    return getLogAppenders().mapToLong(s -> s.getFollower().getMatchIndex()).toArray();
+  }
+
   static Map<RaftPeerId, RaftPeer> newMap(Collection<RaftPeer> peers, String str) {
     Objects.requireNonNull(peers, () -> str + " == null");
     final Map<RaftPeerId, RaftPeer> map = new HashMap<>();
@@ -1222,7 +1230,7 @@ class LeaderStateImpl implements LeaderState {
   }
 
   private class ConfigurationStagingState {
-    private final String name = server.getMemberId() + "-" + JavaUtils.getClassSimpleName(getClass());
+    private final String name = ServerStringUtils.generateUnifiedName(server.getMemberId(), getClass());
     private final Map<RaftPeerId, RaftPeer> newPeers;
     private final Map<RaftPeerId, RaftPeer> newListeners;
     private final PeerConfiguration newConf;
