@@ -17,7 +17,6 @@
  */
 package org.apache.ratis.server.impl;
 
-import java.util.concurrent.CountDownLatch;
 import org.apache.ratis.client.impl.ClientProtoUtils;
 import org.apache.ratis.conf.RaftProperties;
 import org.apache.ratis.metrics.Timekeeper;
@@ -25,11 +24,11 @@ import org.apache.ratis.proto.RaftProtos.AppendEntriesReplyProto;
 import org.apache.ratis.proto.RaftProtos.AppendEntriesReplyProto.AppendResult;
 import org.apache.ratis.proto.RaftProtos.AppendEntriesRequestProto;
 import org.apache.ratis.proto.RaftProtos.CommitInfoProto;
-import org.apache.ratis.proto.RaftProtos.LogInfoProto;
 import org.apache.ratis.proto.RaftProtos.InstallSnapshotReplyProto;
 import org.apache.ratis.proto.RaftProtos.InstallSnapshotRequestProto;
 import org.apache.ratis.proto.RaftProtos.InstallSnapshotResult;
 import org.apache.ratis.proto.RaftProtos.LogEntryProto;
+import org.apache.ratis.proto.RaftProtos.LogInfoProto;
 import org.apache.ratis.proto.RaftProtos.RaftClientRequestProto;
 import org.apache.ratis.proto.RaftProtos.RaftClientRequestProto.TypeCase;
 import org.apache.ratis.proto.RaftProtos.RaftConfigurationProto;
@@ -82,6 +81,8 @@ import org.apache.ratis.server.RaftServerConfigKeys;
 import org.apache.ratis.server.RaftServerRpc;
 import org.apache.ratis.server.impl.LeaderElection.Phase;
 import org.apache.ratis.server.impl.RetryCacheImpl.CacheEntry;
+import org.apache.ratis.server.impl.ServerImplUtils.ConsecutiveIndices;
+import org.apache.ratis.server.impl.ServerImplUtils.NavigableIndices;
 import org.apache.ratis.server.leader.LeaderState;
 import org.apache.ratis.server.metrics.LeaderElectionMetrics;
 import org.apache.ratis.server.metrics.RaftServerMetricsImpl;
@@ -126,6 +127,7 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.CompletionException;
+import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.ThreadLocalRandom;
@@ -204,6 +206,14 @@ class RaftServerImpl implements RaftServer.Division,
           .map(LeaderStateImpl::getFollowerNextIndices)
           .orElse(null);
     }
+
+    @Override
+    public long[] getFollowerMatchIndices() {
+      return role.getLeaderState()
+          .filter(leader -> isLeader())
+          .map(LeaderStateImpl::getFollowerMatchIndices)
+          .orElse(null);
+    }
   }
 
   private final RaftServerProxy proxy;
@@ -250,6 +260,7 @@ class RaftServerImpl implements RaftServer.Division,
   private final ThreadGroup threadGroup;
 
   private final AtomicReference<CompletableFuture<Void>> appendLogFuture;
+  private final NavigableIndices appendLogTermIndices = new NavigableIndices();
 
   RaftServerImpl(RaftGroup group, StateMachine stateMachine, RaftServerProxy proxy, RaftStorage.StartupOption option)
       throws IOException {
@@ -704,7 +715,7 @@ class RaftServerImpl implements RaftServer.Division,
 
   @Override
   public String toString() {
-    return role + " " + state + " " + lifeCycle.getCurrentState();
+    return role + " (" + lifeCycle.getCurrentState() + "): " + state;
   }
 
   RaftClientReply.Builder newReplyBuilder(RaftClientRequest request) {
@@ -1230,7 +1241,7 @@ class RaftServerImpl implements RaftServer.Division,
     LOG.info("{}: takeSnapshotAsync {}", getMemberId(), request);
     assertLifeCycleState(LifeCycle.States.RUNNING);
     assertGroup(getMemberId(), request);
-    Preconditions.assertNotNull(request.getCreate(), "create");
+    Objects.requireNonNull(request.getCreate(), "create == null");
 
     final long creationGap = request.getCreate().getCreationGap();
     long minGapValue = creationGap > 0? creationGap : RaftServerConfigKeys.Snapshot.creationGap(proxy.getProperties());
@@ -1439,7 +1450,7 @@ class RaftServerImpl implements RaftServer.Division,
         shouldShutdown = true;
       }
       reply = toRequestVoteReplyProto(candidateId, getMemberId(),
-          voteGranted, state.getCurrentTerm(), shouldShutdown);
+          voteGranted, state.getCurrentTerm(), shouldShutdown, state.getLastEntry());
       if (LOG.isInfoEnabled()) {
         LOG.info("{} replies to {} vote request: {}. Peer's state: {}",
             getMemberId(), phase, toRequestVoteReplyString(reply), state);
@@ -1622,8 +1633,15 @@ class RaftServerImpl implements RaftServer.Division,
     });
   }
   private CompletableFuture<Void> appendLog(List<LogEntryProto> entries) {
+    final List<ConsecutiveIndices> entriesTermIndices = ConsecutiveIndices.convert(entries);
+    if (!appendLogTermIndices.append(entriesTermIndices)) {
+      // index already exists, return the last future
+      return appendLogFuture.get();
+    }
+
     return appendLogFuture.updateAndGet(f -> f.thenCompose(
-            ignored -> JavaUtils.allOf(state.getLog().append(entries))));
+            ignored -> JavaUtils.allOf(state.getLog().append(entries))))
+        .whenComplete((v, e) -> appendLogTermIndices.removeExisting(entriesTermIndices));
   }
 
   private long checkInconsistentAppendEntries(TermIndex previous, List<LogEntryProto> entries) {
@@ -1650,7 +1668,7 @@ class RaftServerImpl implements RaftServer.Division,
     }
 
     // Check if "previous" is contained in current state.
-    if (previous != null && !state.containsTermIndex(previous)) {
+    if (previous != null && !(appendLogTermIndices.contains(previous) || state.containsTermIndex(previous))) {
       final long replyNextIndex = Math.min(state.getNextIndex(), previous.getIndex());
       LOG.info("{}: Failed appendEntries as previous log entry ({}) is not found", getMemberId(), previous);
       return replyNextIndex;
@@ -1829,6 +1847,7 @@ class RaftServerImpl implements RaftServer.Division,
       break;
     case STATEMACHINELOGENTRY:
       TransactionContext trx = getTransactionContext(next, true);
+      Objects.requireNonNull(trx, "trx == null");
       final ClientInvocationId invocationId = ClientInvocationId.valueOf(next.getStateMachineLogEntry());
       writeIndexCache.add(invocationId.getClientId(), ((TransactionContextImpl) trx).getLogIndexFuture());
 
