@@ -25,6 +25,7 @@ import org.apache.ratis.protocol.ClientId;
 import org.apache.ratis.protocol.Message;
 import org.apache.ratis.protocol.RaftClientReply;
 import org.apache.ratis.protocol.RaftGroupId;
+import org.apache.ratis.protocol.RaftPeer;
 import org.apache.ratis.protocol.RaftPeerId;
 import org.apache.ratis.server.RaftServer;
 import org.apache.ratis.server.RaftServerConfigKeys;
@@ -35,20 +36,21 @@ import org.apache.ratis.server.raftlog.LogEntryHeader;
 import org.apache.ratis.server.raftlog.LogProtoUtils;
 import org.apache.ratis.server.raftlog.RaftLog;
 import org.apache.ratis.server.raftlog.RaftLogBase;
-import org.apache.ratis.thirdparty.com.google.common.base.Preconditions;
 import org.apache.ratis.thirdparty.com.google.protobuf.ByteString;
 import org.apache.ratis.util.AutoCloseableLock;
 import org.apache.ratis.util.CollectionUtils;
 import org.apache.ratis.util.JavaUtils;
+import org.apache.ratis.util.Preconditions;
 import org.apache.ratis.util.ProtoUtils;
 import org.apache.ratis.util.TimeDuration;
-import org.junit.Assert;
-import org.junit.AssumptionViolatedException;
+import org.apache.ratis.util.function.CheckedConsumer;
+import org.junit.jupiter.api.Assumptions;
 import org.junit.jupiter.api.Assertions;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
+import java.lang.ref.WeakReference;
 import java.lang.reflect.Field;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -140,7 +142,7 @@ public interface RaftTestUtil {
 
   static RaftPeerId waitAndKillLeader(MiniRaftCluster cluster) throws InterruptedException {
     final RaftServer.Division leader = waitForLeader(cluster);
-    Assert.assertNotNull(leader);
+    Assertions.assertNotNull(leader);
 
     LOG.info("killing leader = " + leader);
     cluster.killServer(leader.getId());
@@ -149,8 +151,9 @@ public interface RaftTestUtil {
 
   static void waitFor(Supplier<Boolean> check, int checkEveryMillis,
       int waitForMillis) throws TimeoutException, InterruptedException {
-    Preconditions.checkNotNull(check);
-    Preconditions.checkArgument(waitForMillis >= checkEveryMillis);
+    Objects.requireNonNull(check, "check == null");
+    Preconditions.assertTrue(waitForMillis >= checkEveryMillis,
+        () -> "waitFor: " + waitForMillis + " < checkEvery: " + checkEveryMillis);
 
     long st = System.currentTimeMillis();
     boolean result = check.get();
@@ -226,7 +229,7 @@ public interface RaftTestUtil {
           e = log.get(termIndices[i].getIndex());
           if (Arrays.equals(expectedMessages[j].getContent().toByteArray(),
               e.getStateMachineLogEntry().getLogData().toByteArray())) {
-            Assert.assertTrue(predicate.test(e));
+            Assertions.assertTrue(predicate.test(e));
           }
         } catch (IOException exception) {
           exception.printStackTrace();
@@ -339,16 +342,16 @@ public interface RaftTestUtil {
 
   static void assertLogEntries(List<LogEntryProto> entries, long expectedTerm, SimpleMessage... expectedMessages) {
     long logIndex = 0;
-    Assert.assertEquals(expectedMessages.length, entries.size());
+    Assertions.assertEquals(expectedMessages.length, entries.size());
     for (int i = 0; i < expectedMessages.length; i++) {
       final LogEntryProto e = entries.get(i);
-      Assert.assertTrue(e.getTerm() >= expectedTerm);
+      Assertions.assertTrue(e.getTerm() >= expectedTerm);
       if (e.getTerm() > expectedTerm) {
         expectedTerm = e.getTerm();
       }
-      Assert.assertTrue(e.getIndex() > logIndex);
+      Assertions.assertTrue(e.getIndex() > logIndex);
       logIndex = e.getIndex();
-      Assert.assertEquals(expectedMessages[i].getContent(), e.getStateMachineLogEntry().getLogData());
+      Assertions.assertEquals(expectedMessages[i].getContent(), e.getStateMachineLogEntry().getLogData());
     }
   }
 
@@ -462,20 +465,29 @@ public interface RaftTestUtil {
     }
   }
 
-  static RaftPeerId changeLeader(MiniRaftCluster cluster, RaftPeerId oldLeader)
-      throws Exception {
-    return changeLeader(cluster, oldLeader, AssumptionViolatedException::new);
+  static List<RaftPeer> getPeersWithPriority(List<RaftPeer> peers, RaftPeer suggestedLeader) {
+    List<RaftPeer> peersWithPriority = new ArrayList<>();
+    for (RaftPeer peer : peers) {
+      final int priority = peer.equals(suggestedLeader) ? 2 : 1;
+      peersWithPriority.add(RaftPeer.newBuilder(peer).setPriority(priority).build());
+    }
+    return peersWithPriority;
   }
 
-  static RaftPeerId changeLeader(MiniRaftCluster cluster, RaftPeerId oldLeader, Function<String, Exception> constructor)
+  static RaftPeerId changeLeader(MiniRaftCluster cluster, RaftPeerId oldLeader)
       throws Exception {
+    return changeLeader(cluster, oldLeader, Assumptions::abort);
+  }
+
+  static RaftPeerId changeLeader(MiniRaftCluster cluster, RaftPeerId oldLeader,
+      CheckedConsumer<String, Exception> failToChangeLeaderHandler) throws Exception {
     final String name = JavaUtils.getCallerStackTraceElement().getMethodName() + "-changeLeader";
     cluster.setBlockRequestsFrom(oldLeader.toString(), true);
     try {
       return JavaUtils.attemptRepeatedly(() -> {
         final RaftPeerId newLeader = waitForLeader(cluster).getId();
         if (newLeader.equals(oldLeader)) {
-          throw constructor.apply("Failed to change leader: newLeader == oldLeader == " + oldLeader);
+          failToChangeLeaderHandler.accept("Failed to change leader: newLeader == oldLeader == " + oldLeader);
         }
         LOG.info("Changed leader from " + oldLeader + " to " + newLeader);
         return newLeader;
@@ -541,11 +553,11 @@ public interface RaftTestUtil {
   }
 
   static void assertSameLog(RaftLog expected, RaftLog computed) throws Exception {
-    Assert.assertEquals(expected.getLastEntryTermIndex(), computed.getLastEntryTermIndex());
+    Assertions.assertEquals(expected.getLastEntryTermIndex(), computed.getLastEntryTermIndex());
     final long lastIndex = expected.getNextIndex() - 1;
-    Assert.assertEquals(expected.getLastEntryTermIndex().getIndex(), lastIndex);
+    Assertions.assertEquals(expected.getLastEntryTermIndex().getIndex(), lastIndex);
     for(long i = 0; i < lastIndex; i++) {
-      Assert.assertEquals(expected.get(i), computed.get(i));
+      Assertions.assertEquals(expected.get(i), computed.get(i));
     }
   }
 
@@ -576,7 +588,21 @@ public interface RaftTestUtil {
   }
 
   static void assertSuccessReply(RaftClientReply reply) {
-    Assert.assertNotNull("reply == null", reply);
-    Assert.assertTrue("reply is not success: " + reply, reply.isSuccess());
+    Assertions.assertNotNull(reply, "reply == null");
+    Assertions.assertTrue(reply.isSuccess(), "reply is not success: " + reply);
+  }
+
+  static void gc() throws InterruptedException {
+    // use WeakReference to detect gc
+    Object obj = new Object();
+    final WeakReference<Object> weakRef = new WeakReference<>(obj);
+    obj = null;
+
+    // loop until gc has completed.
+    for (int i = 0; weakRef.get() != null; i++) {
+      LOG.info("gc {}", i);
+      System.gc();
+      Thread.sleep(100);
+    }
   }
 }
