@@ -133,7 +133,7 @@ public abstract class MiniRaftCluster implements Closeable {
       default void runWithNewCluster(int numServers, int numListeners, boolean startCluster,
           CheckedConsumer<CLUSTER, Exception> testCase) throws Exception {
         final StackTraceElement caller = JavaUtils.getCallerStackTraceElement();
-        LOG.info("Running " + caller.getMethodName());
+        LOG.info("Running {}", caller.getMethodName());
         final CLUSTER cluster = newCluster(numServers, numListeners);
         try {
           if (startCluster) {
@@ -142,7 +142,7 @@ public abstract class MiniRaftCluster implements Closeable {
           testCase.accept(cluster);
         } catch(Exception t) {
           LOG.info(cluster.printServers());
-          LOG.error("Failed " + caller, t);
+          LOG.error("Failed {}", caller, t);
           throw t;
         } finally {
           cluster.shutdown();
@@ -156,7 +156,7 @@ public abstract class MiniRaftCluster implements Closeable {
       default void runWithSameCluster(int numServers, int numListeners, CheckedConsumer<CLUSTER, Exception> testCase)
           throws Exception {
         final StackTraceElement caller = JavaUtils.getCallerStackTraceElement();
-        LOG.info("Running " + caller.getMethodName());
+        LOG.info("Running {}", caller.getMethodName());
         CLUSTER cluster = null;
         try {
           cluster = getFactory().reuseCluster(numServers, numListeners, getProperties());
@@ -165,7 +165,7 @@ public abstract class MiniRaftCluster implements Closeable {
           if (cluster != null) {
             LOG.info(cluster.printServers());
           }
-          LOG.error("Failed " + caller, t);
+          LOG.error("Failed {}", caller, t);
           throw t;
         }
       }
@@ -317,7 +317,7 @@ public abstract class MiniRaftCluster implements Closeable {
   }
 
   public MiniRaftCluster initServers() {
-    LOG.info("servers = " + servers);
+    LOG.info("servers = {}", servers);
     if (servers.isEmpty()) {
       putNewServers(CollectionUtils.as(group.getPeers(), RaftPeer::getId), true, group);
     }
@@ -348,7 +348,7 @@ public abstract class MiniRaftCluster implements Closeable {
     startServers(servers.values());
 
     this.timer.updateAndGet(t -> t != null? t
-        : JavaUtils.runRepeatedly(() -> LOG.info("TIMED-PRINT: " + printServers()), 10, 10, TimeUnit.SECONDS));
+        : JavaUtils.runRepeatedly(() -> LOG.info("TIMED-PRINT: {}.", printServers()), 10, 10, TimeUnit.SECONDS));
   }
 
   /**
@@ -535,7 +535,7 @@ public abstract class MiniRaftCluster implements Closeable {
   }
 
   public void killServer(RaftPeerId id) {
-    LOG.info("killServer " + id);
+    LOG.info("killServer {}", id);
     servers.get(id).close();
   }
 
