@@ -42,16 +42,21 @@ import org.apache.ratis.server.raftlog.LogProtoUtils;
 import org.apache.ratis.server.raftlog.RaftLog;
 import org.apache.ratis.server.raftlog.RaftLogBase;
 import org.apache.ratis.server.storage.RaftStorageTestUtils;
+import org.apache.ratis.test.tag.Flaky;
 import org.apache.ratis.util.JavaUtils;
 import org.apache.ratis.util.LifeCycle;
 import org.apache.ratis.util.Slf4jUtils;
 import org.apache.ratis.util.TimeDuration;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.event.Level;
 
 import java.io.IOException;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
@@ -61,7 +66,7 @@ import java.util.concurrent.atomic.AtomicReference;
 
 import static java.util.Arrays.asList;
 import static org.apache.ratis.server.impl.RaftServerTestUtil.waitAndCheckNewConf;
-import static org.junit.Assert.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluster>
     extends BaseTest
@@ -91,7 +96,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
       for (int j = 0; j < peersWithPriority.size(); j ++) {
         int priorityInConf = conf.getPeer(peersWithPriority.get(j).getId()).getPriority();
-        Assert.assertEquals(priorityInConf, peersWithPriority.get(j).getPriority());
+        Assertions.assertEquals(priorityInConf, peersWithPriority.get(j).getPriority());
       }
     }
   }
@@ -166,15 +171,15 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
           .setConf(new PeerConfiguration(Arrays.asList(curPeer, newPeer)))
           .setLogEntryIndex(Long.MAX_VALUE / 2)
           .build();
-      Assert.assertTrue(oldNewConf.isSingleMode(curPeer.getId()));
+      Assertions.assertTrue(oldNewConf.isSingleMode(curPeer.getId()));
       RaftServerTestUtil.setRaftConf(leaderServer, groupId, oldNewConf);
       try(RaftClient client = cluster.createClient()) {
         client.admin().transferLeadership(null, leaderServer.getId(), 1000);
       }
 
       final RaftServer.Division newLeader = RaftTestUtil.waitForLeader(cluster);
-      Assert.assertEquals(leaderServer.getId(), newLeader.getId());
-      Assert.assertEquals(oldNewConf, newLeader.getRaftConf());
+      Assertions.assertEquals(leaderServer.getId(), newLeader.getId());
+      Assertions.assertEquals(oldNewConf, newLeader.getRaftConf());
     });
   }
 
@@ -192,8 +197,8 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
             .setServersInNewConf(c1.allPeersInNewConf)
             .setMode(SetConfigurationRequest.Mode.COMPARE_AND_SET)
             .build();
-        assertThrows("Expect change majority error.", SetConfigurationException.class,
-            () -> client.admin().setConfiguration(arguments));
+        assertThrows(SetConfigurationException.class, () -> client.admin().setConfiguration(arguments),
+            "Expect change majority error.");
       }
     });
   }
@@ -259,13 +264,13 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
     try (final RaftClient client = cluster.createClient(leader.getId())) {
       for (int i = 0; i < 10; i++) {
         RaftClientReply reply = client.io().send(new SimpleMessage("m" + i));
-        Assert.assertTrue(reply.isSuccess());
+        Assertions.assertTrue(reply.isSuccess());
       }
       RaftClientReply reply = client.admin().setConfiguration(
           SetConfigurationRequest.Arguments.newBuilder()
           .setServersInNewConf(peers)
           .setMode(SetConfigurationRequest.Mode.ADD).build());
-      Assert.assertTrue(reply.isSuccess());
+      Assertions.assertTrue(reply.isSuccess());
       waitAndCheckNewConf(cluster, change.allPeersInNewConf, 0, null);
     }
     cluster.close();
@@ -286,7 +291,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
     try (final RaftClient client = cluster.createClient(leader.getId())) {
       for (int i = 0; i < 10; i++) {
         RaftClientReply reply = client.io().send(new SimpleMessage("m" + i));
-        Assert.assertTrue(reply.isSuccess());
+        Assertions.assertTrue(reply.isSuccess());
       }
 
       testFailureCase("Can't set configuration in CAS mode ",
@@ -303,7 +308,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
               .setServersInCurrentConf(oldPeers)
               .setMode(SetConfigurationRequest.Mode.COMPARE_AND_SET)
               .build());
-      Assert.assertTrue(reply.isSuccess());
+      Assertions.assertTrue(reply.isSuccess());
       waitAndCheckNewConf(cluster, change.allPeersInNewConf, 0, null);
     }
     cluster.close();
@@ -311,7 +316,8 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
 
 
-  @Test(timeout = 30000)
+  @Test
+  @Timeout(value = 30)
   public void testReconfTwice() throws Exception {
     runWithNewCluster(3, this::runTestReconfTwice);
   }
@@ -323,7 +329,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
         // submit some msgs before reconf
         for (int i = 0; i < STAGING_CATCHUP_GAP * 2; i++) {
           RaftClientReply reply = client.io().send(new SimpleMessage("m" + i));
-          Assert.assertTrue(reply.isSuccess());
+          Assertions.assertTrue(reply.isSuccess());
         }
 
         final AtomicBoolean reconf1 = new AtomicBoolean(false);
@@ -357,8 +363,8 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
         clientThread.start();
 
         latch.await();
-        Assert.assertTrue(reconf1.get());
-        Assert.assertTrue(reconf2.get());
+        Assertions.assertTrue(reconf1.get());
+        Assertions.assertTrue(reconf2.get());
         waitAndCheckNewConf(cluster, finalPeers.get(), 2, null);
         final RaftPeerId leader2 = RaftTestUtil.waitForLeader(cluster).getId();
 
@@ -370,7 +376,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
           // each leader change generates one configuration.
           // expectedConf = 1 (init) + 2*2 (two conf changes) + #leader
           final int expectedConf = leader2.equals(leaderId) ? 6 : 7;
-          Assert.assertEquals(server.getId() + ": " + confManager, expectedConf, confManager.numOfConf());
+          Assertions.assertEquals(expectedConf, confManager.numOfConf(), server.getId() + ": " + confManager);
         });
       }
   }
@@ -389,17 +395,17 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
       LOG.info("Start changing the configuration: {}",
           asList(c1.allPeersInNewConf));
-      Assert.assertFalse(((RaftConfigurationImpl)cluster.getLeader().getRaftConf()).isTransitional());
+      Assertions.assertFalse(((RaftConfigurationImpl)cluster.getLeader().getRaftConf()).isTransitional());
 
       final RaftClientRpc sender = client.getClientRpc();
       final SetConfigurationRequest request = cluster.newSetConfigurationRequest(
           client.getId(), leaderId, c1.allPeersInNewConf);
       try {
         RaftClientReply reply = sender.sendRequest(request);
-        Assert.fail("did not get expected exception " + reply.toString());
+        Assertions.fail("did not get expected exception " + reply.toString());
       } catch (IOException e) {
-        Assert.assertTrue("Got exception " + e,
-            e instanceof ReconfigurationTimeoutException);
+        Assertions.assertTrue(
+           e instanceof ReconfigurationTimeoutException, "Got exception " + e);
       }
 
       // the two new peers have not started yet, the bootstrapping must timeout
@@ -409,10 +415,10 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
       // state so that we still get timeout instead of in-progress exception
       try {
         sender.sendRequest(request);
-        Assert.fail("did not get expected exception");
+        Assertions.fail("did not get expected exception");
       } catch (IOException e) {
-        Assert.assertTrue("Got exception " + e,
-            e instanceof ReconfigurationTimeoutException);
+        Assertions.assertTrue(
+           e instanceof ReconfigurationTimeoutException, "Got exception " + e);
       }
 
       // start the two new peers
@@ -420,7 +426,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
       for (RaftPeer np : c1.newPeers) {
         cluster.restartServer(np.getId(), false);
       }
-      Assert.assertTrue(client.admin().setConfiguration(c1.allPeersInNewConf).isSuccess());
+      Assertions.assertTrue(client.admin().setConfiguration(c1.allPeersInNewConf).isSuccess());
     }
   }
 
@@ -440,8 +446,8 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
       try (final RaftClient client = cluster.createClient(leaderId)) {
         final PeerChanges c1 = cluster.addNewPeers(2, true);
 
-        assertThrows("Expect change majority error.", SetConfigurationException.class,
-            () -> client.admin().setConfiguration(c1.allPeersInNewConf));
+        assertThrows(SetConfigurationException.class, () -> client.admin().setConfiguration(c1.allPeersInNewConf),
+            "Expect change majority error.");
       }
     });
   }
@@ -462,7 +468,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
         // submit some msgs before reconf
         for (int i = 0; i < STAGING_CATCHUP_GAP * 2; i++) {
           RaftClientReply reply = client.io().send(new SimpleMessage("m" + i));
-          Assert.assertTrue(reply.isSuccess());
+          Assertions.assertTrue(reply.isSuccess());
         }
 
         final PeerChanges c1 = cluster.addNewPeers(numNewPeer, startNewPeer);
@@ -498,7 +504,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
           final RaftServer.Division d = cluster.getDivision(newPeer.getId());
           RaftTestUtil.waitFor(() -> leaderLog.getEntries(0, Long.MAX_VALUE).length
                   == d.getRaftLog().getEntries(0, Long.MAX_VALUE).length, 300, 15000);
-          Assert.assertArrayEquals(leaderLog.getEntries(0, Long.MAX_VALUE),
+          Assertions.assertArrayEquals(leaderLog.getEntries(0, Long.MAX_VALUE),
               d.getRaftLog().getEntries(0, Long.MAX_VALUE));
         }
       }
@@ -509,6 +515,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
    * retrying.
    */
   @Test
+  @Flaky("RATIS-2251")
   public void testKillLeaderDuringReconf() throws Exception {
     // originally 3 peers
     runWithNewCluster(3, this::runTestKillLeaderDuringReconf);
@@ -546,7 +553,7 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
       // the leader cannot generate the (old, new) conf, and it will keep
       // bootstrapping the 1 new peer since it has not started yet.
-      Assert.assertFalse(((RaftConfigurationImpl)cluster.getLeader().getRaftConf()).isTransitional());
+      Assertions.assertFalse(((RaftConfigurationImpl)cluster.getLeader().getRaftConf()).isTransitional());
 
       // (0) the first conf entry, (1) the 1st setConf entry, (2) a metadata entry
       // (3) new current conf entry  (4) a metadata entry
@@ -556,11 +563,11 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
           LOG.info("{}", LogProtoUtils.toLogEntryString(e));
         }
         final long commitIndex = leaderLog.getLastCommittedIndex();
-        Assert.assertTrue("commitIndex = " + commitIndex + " > 2", commitIndex <= 2);
+        Assertions.assertTrue(commitIndex <= 2, "commitIndex = " + commitIndex + " > 2");
       }
 
       final RaftPeerId killed = RaftTestUtil.waitAndKillLeader(cluster);
-      Assert.assertEquals(leaderId, killed);
+      Assertions.assertEquals(leaderId, killed);
       final RaftPeerId newLeaderId = RaftTestUtil.waitForLeader(cluster).getId();
       LOG.info("newLeaderId: {}", newLeaderId);
       TimeDuration.valueOf(1500, TimeUnit.MILLISECONDS).sleep();
@@ -612,13 +619,13 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
       // no real configuration change in the request
       final RaftClientReply reply = client.admin().setConfiguration(cluster.getPeers().toArray(RaftPeer.emptyArray()));
-      Assert.assertTrue(reply.isSuccess());
+      Assertions.assertTrue(reply.isSuccess());
       final long newCommittedIndex = leaderLog.getLastCommittedIndex();
       for(long i = committedIndex + 1; i <= newCommittedIndex; i++) {
         final LogEntryProto e = leaderLog.get(i);
-        Assert.assertTrue(e.hasMetadataEntry());
+        Assertions.assertTrue(e.hasMetadataEntry());
       }
-      Assert.assertSame(confBefore, cluster.getLeader().getRaftConf());
+      Assertions.assertSame(confBefore, cluster.getLeader().getRaftConf());
     }
   }
 
@@ -688,8 +695,8 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
       for (int i = 0; i < 10 && !confChanged.get(); i++) {
         Thread.sleep(1000);
       }
-      Assert.assertTrue(confChanged.get());
-      Assert.assertTrue(caughtException.get());
+      Assertions.assertTrue(confChanged.get());
+      Assertions.assertTrue(caughtException.get());
     } finally {
       LOG_SYNC_DELAY.clear();
     }
@@ -755,11 +762,11 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
       // wait till the old leader persist the new conf
       JavaUtils.attemptRepeatedly(() -> {
-        Assert.assertTrue(log.getFlushIndex() >= confIndex);
+        Assertions.assertTrue(log.getFlushIndex() >= confIndex);
         return null;
       }, 10, sleepTime, "FLUSH", LOG);
       final long committed = log.getLastCommittedIndex();
-      Assert.assertTrue(committed < confIndex);
+      Assertions.assertTrue(committed < confIndex);
 
       // unblock the old leader
       BlockRequestHandlingInjection.getInstance().unblockReplier(leaderId.toString());
@@ -767,14 +774,14 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
 
       // the client should get NotLeaderException
       clientThread.join(5000);
-      Assert.assertTrue(gotNotLeader.get());
+      Assertions.assertTrue(gotNotLeader.get());
 
       // the old leader should have truncated the setConf from the log
       JavaUtils.attemptRepeatedly(() -> {
-        Assert.assertTrue(log.getLastCommittedIndex() >= confIndex);
+        Assertions.assertTrue(log.getLastCommittedIndex() >= confIndex);
         return null;
       }, 10, ONE_SECOND, "COMMIT", LOG);
-      Assert.assertTrue(log.get(confIndex).hasConfigurationEntry());
+      Assertions.assertTrue(log.get(confIndex).hasConfigurationEntry());
       log2 = null;
     } finally {
       RaftStorageTestUtils.printLog(log2, s -> LOG.info(s));
@@ -830,8 +837,8 @@ public abstract class RaftReconfigurationBaseTest<CLUSTER extends MiniRaftCluste
       for (int i = 0; !success.get() && i < 5; i++) {
         Thread.sleep(1000);
       }
-      Assert.assertTrue(success.get());
-      Assert.assertTrue(caughtNotReady.get());
+      Assertions.assertTrue(success.get());
+      Assertions.assertTrue(caughtNotReady.get());
     } finally {
       LEADER_PLACE_HOLDER_DELAY.clear();
       cluster.shutdown();
