@@ -36,14 +36,14 @@ import org.apache.ratis.server.DataStreamMap;
 import org.apache.ratis.server.RaftServer;
 import org.apache.ratis.server.impl.RaftServerTestUtil;
 import org.apache.ratis.util.NetUtils;
-import org.junit.Before;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-@Ignore
+@Disabled
 public class TestNettyDataStreamWithMock extends DataStreamBaseTest {
   static RaftPeer newRaftPeer(RaftServer server) {
     return RaftPeer.newBuilder()
@@ -53,18 +53,24 @@ public class TestNettyDataStreamWithMock extends DataStreamBaseTest {
         .build();
   }
 
-  @Before
+  @BeforeEach
   public void setup() {
     properties = new RaftProperties();
     RaftConfigKeys.DataStream.setType(properties, SupportedDataStreamType.NETTY);
   }
 
-  RaftServer.Division mockDivision(RaftServer server) {
+
+  RaftServer.Division mockDivision(RaftServer server, RaftGroupId groupId) {
     final RaftServer.Division division = mock(RaftServer.Division.class);
     when(division.getRaftServer()).thenReturn(server);
     when(division.getRaftConf()).thenAnswer(i -> getRaftConf());
 
     final MultiDataStreamStateMachine stateMachine = new MultiDataStreamStateMachine();
+    try {
+      stateMachine.initialize(server, groupId, null);
+    } catch (IOException e) {
+      throw new IllegalStateException(e);
+    }
     when(division.getStateMachine()).thenReturn(stateMachine);
 
     final DataStreamMap streamMap = RaftServerTestUtil.newDataStreamMap(server.getId());
@@ -95,7 +101,7 @@ public class TestNettyDataStreamWithMock extends DataStreamBaseTest {
       when(raftServer.getId()).thenReturn(peerId);
       when(raftServer.getPeer()).thenReturn(RaftPeer.newBuilder().setId(peerId).build());
       if (getStateMachineException == null) {
-        final RaftServer.Division myDivision = mockDivision(raftServer);
+        final RaftServer.Division myDivision = mockDivision(raftServer, groupId);
         when(raftServer.getDivision(Mockito.any(RaftGroupId.class))).thenReturn(myDivision);
       } else {
         when(raftServer.getDivision(Mockito.any(RaftGroupId.class))).thenThrow(getStateMachineException);
@@ -108,8 +114,8 @@ public class TestNettyDataStreamWithMock extends DataStreamBaseTest {
         submitException != null ? submitException : leaderException, getStateMachineException);
   }
 
-  void runTestMockCluster(RaftGroupId groupId, List<RaftServer> raftServers, ClientId clientId, int bufferSize, int bufferNum,
-      Exception expectedException, Exception headerException) throws Exception {
+  void runTestMockCluster(RaftGroupId groupId, List<RaftServer> raftServers, ClientId clientId, int bufferSize,
+      int bufferNum, Exception expectedException, Exception headerException) throws Exception {
     try {
       final List<RaftPeer> peers = raftServers.stream()
           .map(TestNettyDataStreamWithMock::newRaftPeer)
